==> vue.vue-eslint-parser-0.1.0.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import defaultParserInterface from 'astql/utils/defaultParserInterface';
import pkg from 'vue-eslint-parser/package.json';
var ID = 'vue-eslint-parser';
export default _extends({}, defaultParserInterface, {
  id: ID,
  displayName: ID,
  version: pkg.version,
  homepage: pkg.homepage,
  locationProps: new Set(['start', 'end']),
  typeProps: new Set(['tag']),
  loadParser: function loadParser(callback) {
    require('astql/utils/multiple-require')(['vue-eslint-parser'], callback);
  },
  parse: function parse(parser, code, options) {
    if (Object.keys(options).length === 0) {
      options = this.getDefaultOptions();
    }

    return parser.parse(code, options);
  },
  nodeToRange: function nodeToRange(node) {
    if (node.type || node.name) {
      return node.range;
    }
  },
  opensByDefault: function opensByDefault(node, key) {
    return key === 'children';
  },
  getNodeName: function getNodeName(node) {
    return node.tag;
  },
  getDefaultOptions: function getDefaultOptions() {
    return {
      ecmaVersion: 10,
      sourceType: 'module',
      vueFeatures: {
        filter: true,
        interpolationAsNonHTML: false
      }
    };
  },
  _getSettingsConfiguration: function _getSettingsConfiguration() {
    var defaultOptions = this.getDefaultOptions();
    return {
      fields: [['ecmaVersion', [3, 5, 6, 7, 8, 9, 10, 11], function (value) {
        return Number(value);
      }], ['sourceType', ['script', 'module']], {
        key: 'vueFeatures',
        title: 'vueFeatures',
        fields: Object.keys(defaultOptions.vueFeatures),
        settings: function settings(_settings) {
          return _settings.vueFeatures || _extends({}, defaultOptions.vueFeatures);
        }
      }]
    };
  },
  _ignoredProperties: new Set(['parent', 'tokens'])
});

==> vue.vue-eslint-parser-0.1.1.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import { multipleRequire } from 'astql';
import defaultParserInterface from 'astql/utils/defaultParserInterface';
import pkg from 'vue-eslint-parser/package.json';
var ID = 'vue-eslint-parser';
export default _extends({}, defaultParserInterface, {
  id: ID,
  displayName: ID,
  version: pkg.version,
  homepage: pkg.homepage,
  locationProps: new Set(['start', 'end']),
  typeProps: new Set(['tag']),
  loadParser: function loadParser(callback) {
    multipleRequire(['vue-eslint-parser'], callback);
  },
  parse: function parse(parser, code, options) {
    if (Object.keys(options).length === 0) {
      options = this.getDefaultOptions();
    }

    return parser.parse(code, options);
  },
  nodeToRange: function nodeToRange(node) {
    if (node.type || node.name) {
      return node.range;
    }
  },
  opensByDefault: function opensByDefault(node, key) {
    return key === 'children';
  },
  getNodeName: function getNodeName(node) {
    return node.tag;
  },
  getDefaultOptions: function getDefaultOptions() {
    return {
      ecmaVersion: 10,
      sourceType: 'module',
      vueFeatures: {
        filter: true,
        interpolationAsNonHTML: false
      }
    };
  },
  _getSettingsConfiguration: function _getSettingsConfiguration() {
    var defaultOptions = this.getDefaultOptions();
    return {
      fields: [['ecmaVersion', [3, 5, 6, 7, 8, 9, 10, 11], function (value) {
        return Number(value);
      }], ['sourceType', ['script', 'module']], {
        key: 'vueFeatures',
        title: 'vueFeatures',
        fields: Object.keys(defaultOptions.vueFeatures),
        settings: function settings(_settings) {
          return _settings.vueFeatures || _extends({}, defaultOptions.vueFeatures);
        }
      }]
    };
  },
  _ignoredProperties: new Set(['parent', 'tokens'])
});
